﻿
[CmdLetBinding()]
param
(
    [Parameter(Mandatory=$true,Position=0,HelpMessage="You must set the Template file path" )]
        [string]$templateFile,
    [Parameter(Mandatory=$true,Position=1,HelpMessage="You must set the Parameters file path" )]
        [string]$parameterFile,
    [Parameter(Mandatory=$true,Position=2,HelpMessage="THe Resource Group name must be defined" )]
        [string]$resourceGroupName
)
Clear-Host
$badParameters=$false
if  (-not (Test-Path $templateFile -PathType leaf))
{
    Write-Host "ERROR: The template file $templateFile do not exist" -ForegroundColor Red
    $badParameters=$true
}
if  (-not (Test-Path $parameterFile -PathType leaf))
{
    Write-Host "ERROR: The parameters file $parameterFile do not exist" -ForegroundColor Red
    $badParameters=$true
}
<# 
    NOTE: remove the #» to execute the commands 
    to check and /or install the modules
#>
#	Check you have the Azure Snap-in installed in your environment
        #»Get-InstalledModule -Name Az  
#	If there is no module for az, install it
        #Install-Module -Name Az -AllowClobber -Force
#Load the Azure Snap-in
Import-Module -Name Az 
#Connect to your Azure Account
Connect-AzAccount
#Check if Resource Group exists
$rg=Get-AzResourceGroup -Name $resourceGroupName
if($rg -eq $null)
{
    Write-Host "ERROR: The Resource Group $resourceGroupName do not exist in the current subscription" -ForegroundColor Red
    $badParameters=$true
}
if($badParameters)
{
    return
}

#Deploy the Template
New-AzResourceGroupDeployment `
    -ResourceGroupName $resourceGroupName `
    -TemplateFile $templateFile `
    -TemplateParameterFile $parameterFile